"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};

// src/index.ts
var src_exports = {};
__export(src_exports, {
  SpheronDealClient: () => SpheronDealClient,
  default: () => src_default
});
module.exports = __toCommonJS(src_exports);
var import_fs = __toESM(require("fs"));
var import_core = require("@spheron/core");
var import_storage = require("@spheron/storage");
var import_path = __toESM(require("path"));
var import_cids = __toESM(require("cids"));

// src/utils.ts
var import_child_process = require("child_process");
var crypto = __toESM(require("crypto"));
var executeCmd = (cmd) => {
  return new Promise((resolve, reject) => {
    (0, import_child_process.exec)(cmd, (error, stdout, stderr) => {
      if (!error) {
        resolve(stdout);
      } else {
        reject(stderr);
      }
    });
  });
};
var generateRandomHexString = (length) => {
  const buffer = crypto.randomBytes(length);
  const randomHexString = buffer.toString("hex");
  return randomHexString.slice(randomHexString.length / 2);
};
var generateRandomName = (fileName) => {
  const randomString = generateRandomHexString(6);
  return `${fileName}-${randomString}`;
};

// src/index.ts
var SpheronDealClient = class {
  constructor(configuration) {
    this.generateCarCommandPath = import_path.default.relative(
      ".",
      "node_modules/@spheron/fvm-deal-utils/lib/generate-car/generate-car"
    );
    this.generateCarFile = (filePath, outDir) => __async(this, null, function* () {
      const cmd = `${this.generateCarCommandPath} --single -i ${filePath} -o ${outDir} -p ${import_path.default.dirname(filePath)}/`;
      const result = yield executeCmd(cmd);
      const data = JSON.parse(result);
      const cidHexRaw = new import_cids.default(data.PieceCid).toString("base16");
      const cidHex = "0x" + cidHexRaw.substring(1);
      const carFiles = import_fs.default.readdirSync(outDir);
      if (!import_fs.default.statSync(outDir + "/" + carFiles[0]).isFile()) {
        throw new Error("Car file was not generated");
      }
      return {
        pieceSize: data.PieceSize,
        size: data.Ipld.Link[0].Size,
        pieceCid: cidHex,
        dataCid: data.DataCid,
        filePath: import_path.default.resolve(outDir + "/" + carFiles[0]),
        carName: data.PieceCid
      };
    });
    if (!configuration.token) {
      throw new Error("Token is not provided.");
    }
    this.configuration = configuration;
  }
  getFvmMetadata(filePath, configuration) {
    return __async(this, null, function* () {
      this.validateFilePath(filePath);
      this.validateConfiguration(configuration);
      const outputDir = this.generateUniqueDirectory(filePath);
      try {
        const carFileResults = yield this.generateCarFile(filePath, outputDir);
        const spheronStorage = new import_storage.SpheronClient(this.configuration);
        const uploadResult = yield spheronStorage.upload(
          carFileResults.filePath,
          {
            protocol: import_core.ProtocolEnum.IPFS,
            name: configuration.name,
            onUploadInitiated: configuration.onUploadInitiated,
            onChunkUploaded: configuration.onChunkUploaded
          }
        );
        return {
          pieceSize: carFileResults.pieceSize,
          size: carFileResults.size,
          pieceCid: carFileResults.pieceCid,
          dataCid: carFileResults.dataCid,
          carLink: `${uploadResult.protocolLink}/${import_path.default.basename(
            carFileResults.filePath
          )}`,
          carName: carFileResults.carName,
          uploadId: uploadResult.uploadId
        };
      } finally {
        yield import_fs.default.promises.rm(outputDir, { recursive: true });
      }
    });
  }
  generateUniqueDirectory(filePath) {
    const fileDir = import_path.default.dirname(filePath);
    const fileName = import_path.default.basename(filePath);
    let uniqueDirectory = generateRandomName(fileName);
    let counter = 0;
    while (import_fs.default.existsSync(`${fileDir}/${uniqueDirectory}`) && counter++ < 5) {
      uniqueDirectory = generateRandomName(fileName);
    }
    if (counter == 5) {
      throw new Error("Something went wrong. Try again.");
    }
    const outDir = `${fileDir}/${uniqueDirectory}`;
    import_fs.default.mkdirSync(outDir);
    return outDir;
  }
  validateFilePath(filePath) {
    if (!filePath) {
      throw new Error("File path is not specified.");
    }
    if (!import_fs.default.statSync(import_path.default.resolve(filePath)).isFile()) {
      throw new Error("The provided file path does not point to a valid file.");
    }
  }
  validateConfiguration(config) {
    if (!config.name) {
      throw new Error("Bucket name is not provided.");
    }
  }
};
var src_default = SpheronDealClient;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  SpheronDealClient
});
